@@ -51,7 +51,7 @@ def test_classes_recurrent(p, recurrent_classes):
 
     assert actual == expected
 
-    actual = sum([len(i) for i in mc.recurrent_classes])
+    actual = sum(len(i) for i in mc.recurrent_classes)
     expected = len({state for recurrent_class in recurrent_classes for state in recurrent_class})
 
     assert actual == expected
@@ -66,7 +66,7 @@ def test_classes_transient(p, transient_classes):
 
     assert actual == expected
 
-    actual = sum([len(i) for i in mc.transient_classes])
+    actual = sum(len(i) for i in mc.transient_classes)
     expected = len({state for transient_class in transient_classes for state in transient_class})
 
     assert actual == expected
@@ -126,7 +126,7 @@ def test_states_absorbing(p, recurrent_classes, absorbing_states):
 
     assert actual == expected
 
-    actual = sum([1 if len(recurrent_class) == 1 and recurrent_class[0] in actual else 0 for recurrent_class in recurrent_classes])
+    actual = sum(1 if len(recurrent_class) == 1 and recurrent_class[0] in actual else 0 for recurrent_class in recurrent_classes)
     expected = len(absorbing_states)
 
     assert actual == expected
